==> qore-1.18.0.tar.bz2: qore-1.18.0/docs/modules/EmpathicBuildingDataProvider/html/hierarchy.js <==
var hierarchy =
[
    [ "DataProvider::AbstractDataProvider", "../../DataProvider/html/class_data_provider_1_1_abstract_data_provider.html", [
      [ "EmpathicBuildingDataProvider::EmpathicBuildingDataProvider", "class_empathic_building_data_provider_1_1_empathic_building_data_provider.html", null ],
      [ "EmpathicBuildingDataProvider::EmpathicBuildingMeasurementsCreateDataProvider", "class_empathic_building_data_provider_1_1_empathic_building_measurements_create_data_provider.html", null ],
      [ "EmpathicBuildingDataProvider::EmpathicBuildingMeasurementsDataProvider", "class_empathic_building_data_provider_1_1_empathic_building_measurements_data_provider.html", null ]
    ] ],
    [ "DataProvider::AbstractDataProviderFactory", "../../DataProvider/html/class_data_provider_1_1_abstract_data_provider_factory.html", [
      [ "EmpathicBuildingDataProvider::EmpathicBuildingDataProviderFactory", "class_empathic_building_data_provider_1_1_empathic_building_data_provider_factory.html", null ]
    ] ],
    [ "Qore::Serializable", "../../../lang/html/class_qore_1_1_serializable.html", [
      [ "DataProvider::AbstractDataProviderType", "../../DataProvider/html/class_data_provider_1_1_abstract_data_provider_type.html", [
        [ "DataProvider::QoreDataType", "../../DataProvider/html/class_data_provider_1_1_qore_data_type.html", [
          [ "DataProvider::HashDataType", "../../DataProvider/html/class_data_provider_1_1_hash_data_type.html", [
            [ "EmpathicBuildingDataProvider::EmpathicBuildingMeasurementEventType", "class_empathic_building_data_provider_1_1_empathic_building_measurement_event_type.html", null ],
            [ "EmpathicBuildingDataProvider::EmpathicBuildingMeasurementsCreateRequestDataType", "class_empathic_building_data_provider_1_1_empathic_building_measurements_create_request_data_type.html", null ]
          ] ]
        ] ]
      ] ]
    ] ],
    [ "EmpathicBuildingDataProvider::SoftBoolStringType", "class_empathic_building_data_provider_1_1_soft_bool_string_type.html", null ]
];

==> qore-1.19.2.tar.bz2: qore-1.19.2/docs/modules/EmpathicBuildingDataProvider/html/hierarchy.js <==
var hierarchy =
[
    [ "DataProvider::AbstractDataProvider", "../../DataProvider/html/class_data_provider_1_1_abstract_data_provider.html", [
      [ "EmpathicBuildingDataProvider::EmpathicBuildingDataProviderBase", "class_empathic_building_data_provider_1_1_empathic_building_data_provider_base.html", [
        [ "EmpathicBuildingDataProvider::EmpathicBuildingDataProvider", "class_empathic_building_data_provider_1_1_empathic_building_data_provider.html", null ],
        [ "EmpathicBuildingDataProvider::EmpathicBuildingMeasurementsCreateDataProvider", "class_empathic_building_data_provider_1_1_empathic_building_measurements_create_data_provider.html", null ],
        [ "EmpathicBuildingDataProvider::EmpathicBuildingMeasurementsDataProvider", "class_empathic_building_data_provider_1_1_empathic_building_measurements_data_provider.html", null ]
      ] ]
    ] ],
    [ "DataProvider::AbstractDataProviderFactory", "../../DataProvider/html/class_data_provider_1_1_abstract_data_provider_factory.html", [
      [ "EmpathicBuildingDataProvider::EmpathicBuildingDataProviderFactory", "class_empathic_building_data_provider_1_1_empathic_building_data_provider_factory.html", null ]
    ] ],
    [ "Qore::Serializable", "../../../lang/html/class_qore_1_1_serializable.html", [
      [ "DataProvider::AbstractDataProviderType", "../../DataProvider/html/class_data_provider_1_1_abstract_data_provider_type.html", [
        [ "DataProvider::QoreDataType", "../../DataProvider/html/class_data_provider_1_1_qore_data_type.html", [
          [ "DataProvider::HashDataType", "../../DataProvider/html/class_data_provider_1_1_hash_data_type.html", [
            [ "EmpathicBuildingDataProvider::EmpathicBuildingMeasurementEventType", "class_empathic_building_data_provider_1_1_empathic_building_measurement_event_type.html", null ],
            [ "EmpathicBuildingDataProvider::EmpathicBuildingMeasurementsCreateRequestDataType", "class_empathic_building_data_provider_1_1_empathic_building_measurements_create_request_data_type.html", null ]
          ] ]
        ] ]
      ] ]
    ] ],
    [ "EmpathicBuildingDataProvider::SoftBoolStringType", "class_empathic_building_data_provider_1_1_soft_bool_string_type.html", null ]
];
